math.randomseed(os.time()) math.random()

local Astar = require 'Astar'  -- load library, returns a set of functions in a 'Astar' table

function love.load()
  map = {
    w = 38,
    h = 23,
    ox = 64,
    oy = 0,
    ts = 32,
    tile = {}
  }

  for y = 0, map.h + 1 do
    map.tile[y] = {}
    for x = 0, map.w + 1 do
      map.tile[y][x] = 0
    end
  end

  Astar(map.tile)
  Astar:setObstValue(1)
  Astar:enableDiagonalMove()
  Astar:setSearchDepth(0)

  person = {}

  for i = 1, 1 do
    person[i] = {
      x = math.random(1, map.w),
      y = math.random(1, map.h),
      mt = 0,
      path = nil,
    }
  end
end

function love.update(dt)
  for i, p in pairs(person) do
    if p.path == nil then
      Astar:setInitialNode(p.x, p.y)
      Astar:setFinalNode(math.random(1, map.w), math.random(1, map.h))
      p.path = Astar:getPath()
      p.cur = 0
      p.pathLen = #p.path
    else
      p.mt = p.mt - dt
      if p.mt <= 0 then
        p.cur = p.cur + 1
        if p.cur > p.pathLen then
          p.path = nil
        else
          p.x = p.path[p.cur].x
          p.y = p.path[p.cur].y
        end
        p.mt = .1
      end
    end
  end
end

function love.draw()
  for y = 1, map.h do
    for x = 1, map.w do
      local t = map.tile[y][x]
      love.graphics.setColor(255,255,255)
      love.graphics.rectangle("line", x * map.ts, y * map.ts, map.ts, map.ts)
    end
  end

  for i, p in pairs(person) do
    love.graphics.setColor(255,0,0)
    love.graphics.circle("fill", p.x * map.ts + (map.ts / 2), p.y * map.ts + (map.ts / 2), (map.ts / 2))
    if p.path then
      for i, t in pairs(p.path) do
        love.graphics.setColor(0,255,0)
        love.graphics.circle("fill", t.x * map.ts + (map.ts / 2), t.y * map.ts + (map.ts / 2), 2)
      end
    end
  end
end

function love.mousepressed(x, y, b)

end

function love.keypressed(k)
  print(k)
end

dir = {
  [1] = "left",
  [2] = "up",
  [3] = "right",
  [4] = "down"
}

function dirNum(d)
  local h, v
  if d == "left" then
    h, v = -1, 0
  elseif d == "up" then
    h, v = 0, -1
  elseif d == "right" then
    h, v = 1, 0
  elseif d == "down" then
    h, v = 0, 1
  end
  return h, v
end